/*------------------------------------------------------- File Description -*\

  @doc PublicDspFwkSdkApi

  Copyright (C) 2005-2007 Odin TeleSystems Inc., All Rights Reserved

  Odin TeleSystems Inc.

  OTX DSP Framework Software Development Kit (SDK)

  @module

    iDspFwk.h | xDM Codec Engine Extension to support OTX DSP FWK.

  @contents2
  iDspFwk.h |


\*--------------------------------------------------------------------------*/

#ifndef ODXDM_IXDMLINK_H_
#define ODXDM_IXDMLINK_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/xdais/xdas.h>
#include <ti/xdais/ialg.h>

#ifndef __linux__
#include "Dsp64Types.h"
#else
#include "OtxType.h"
#endif

#define IXDMLINK_EOK      0
#define IXDMLINK_EFAIL    -1
#define IXDMLINK_ERUNTIME -2

/**
 *  @brief      This must be the first field of all IXDMLINK instance objects.
 */
typedef struct IXDMLINK_Obj {
    struct IXDMLINK_Fxns *fxns;
} IXDMLINK_Obj;

/**
 *  @brief      Opaque handle to an IXDMLINK object.
 */
typedef struct IXDMLINK_Obj *IXDMLINK_Handle;


// Init params
typedef struct IXDMLINK_InitParams {
//   XDAS_Int32  size;                  // Safety reason
   OTX_UINT32  nTimeslotsPerFrame;    // Number of timeslots in PCM frame: 32 (2 mbps), 64 (4 mbps), 128 (8 mbps), 256 (16 mbps)
//   OTX_UINT32  coDevices;             // Number of OTX DSP logical devices
} IXDMLINK_Params;

// Process params
typedef struct IXDMLINK_InArgs {
    XDAS_Int32 inBufSize;
    XDAS_Int32 outBufSize;
    XDAS_Int32 evBufSize;
    XDAS_Int32 inBufValidBytes;
} IXDMLINK_InArgs;

typedef struct IXDMLINK_OutArgs {
    XDAS_Int32 outBufValidBytes;
    XDAS_Int32 evBufValidBytes;
} IXDMLINK_OutArgs;

typedef IALG_Cmd IXDMLINK_Cmd;

#define IXDMLINK_SETPARAMS  0       
#define IXDMLINK_OTXCONTROL 1       // Wrapped IO control code is transferred inside
#define IXDMLINK_DEBUG	   2       // Debug interface

#if 1 //(sizeof(OTX_HANDLE) == sizeof(unsigned long))
  #define HANDLE_LONG
#endif

// Control Params
#ifdef __linux__
  #define XDMATTR_PACKED __attribute__ ((packed))
#else
  #define XDMATTR_PACKED
#endif  

#define XDMLINK_HDR_SIZE	6

#define XDMLINK_SIZE		0          // IN Size of this structure (for the safety)
#define XDMLINK_NCODE		1          // IN Device IO Control Code 
#define XDMLINK_NTASKREF	2          // IN User specified Task Ref field.
#define XDMLINK_NDATALEN	3          // IN/OUT Data size contained in pData
#define XDMLINK_COIOBUF		4          // IN IoCtl Buffer size
#define XDMLINK_HHANDLE		5          // Device Handle (32 - bits)
  
typedef OTX_UINT32 IXDMLINK_IoHeaderS[XDMLINK_HDR_SIZE];

// {
//  OTX_UINT32	size;           
//  OTX_UINT32	nCode;          // IN Device IO Control Code
//  OTX_UINT32	nTaskRef;       // IN User specified Task Ref field.
 
//  OTX_UINT32    nDataLen;       // IN/OUT Data size contained in pData
//  OTX_UINT32    coDataBuf;      // IN IoCtl Buffer size
//  OTX_UINT32	hHandle;        // Device Handle (32 - bits)
//} IXDMLINK_IoHeaderS XDMATTR_PACKED;

typedef struct IXDMLINK_Fxns{
    IALG_Fxns   ialg;           // !Should be first
    XDAS_Int32 (*process)(
      IXDMLINK_Handle handle, 
      XDAS_Int8 *inBuf, XDAS_Int8 *outBuf,              // PCM buffers
      IXDMLINK_InArgs *inArgs, IXDMLINK_OutArgs *outArgs,  // Data formats
      XDAS_Int8 *pEvents
    );
    XDAS_Int32 (*control1)(
      IXDMLINK_Handle handle, 
      XDAS_Int8 *inBuf, XDAS_Int8 *outBuf,              // PCM buffers
      IXDMLINK_InArgs *inArgs, IXDMLINK_OutArgs *outArgs,  // Data formats
      XDAS_Int8 *pEvents
    );
/*    
    XDAS_Int32 (*control)(
      IXDMLINK_Handle hFwk, 
      IXDMLINK_Cmd nId,  
      IXDMLINK_IoHeaderS *pParams, 
      XDAS_Int8 *pInBuf,
      XDAS_Int8 *pOutBuf,
      XDAS_Int8 *pEvents
    );
*/    
} IXDMLINK_Fxns;


#ifdef __cplusplus
}
#endif
 

#endif

/*--------------------------------------------------------------------------*\

  Copyright (C) Odin TeleSystems Inc., 2005-2007


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

\*--------------------------------------------------------------------------*/


